==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/HinemosAgentCore/src/com/clustercontrol/hinemosagent/action/GetAgent.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.hinemosagent.action;

import java.rmi.AccessException;
import java.rmi.RemoteException;
import java.util.ArrayList;

import javax.ejb.CreateException;
import javax.ejb.FinderException;
import javax.naming.NamingException;

import org.eclipse.jface.dialogs.MessageDialog;
import org.quartz.SchedulerException;

import com.clustercontrol.hinemosagent.ejb.session.MonitorAgentController;
import com.clustercontrol.hinemosagent.util.EjbConnectionManager;
import com.clustercontrol.monitor.run.bean.MonitorInfo;
import com.clustercontrol.util.Messages;

/**
 * Hinemos Agentƻ륯饹Ǥ
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class GetAgent {

    /**
     * Hinemos Agentƻ֤ޤ
     * 
     * @param monitorId ִƻID
     * @return Hinemos Agentƻ
     */
    public MonitorInfo getAgent(String monitorId) {
    	
    	MonitorAgentController agent = EjbConnectionManager.getConnectionManager().getAgentController();

    	MonitorInfo info = null;

    	try {
			info = agent.getAgentInfo(monitorId);
		} catch (RemoteException e) {
			if(e instanceof AccessException){
				// ʤξ硢顼ɽ
	            MessageDialog.openInformation(null, Messages.getString("message"),
	                    Messages.getString("message.accesscontrol.16"));
			}
		} catch (CreateException e) {
			e.printStackTrace();
		} catch (FinderException e) {
			e.printStackTrace();
		} catch (SchedulerException e) {
			e.printStackTrace();
		} catch (NamingException e) {
			e.printStackTrace();
		}

        return info;
    }
    
    /**
     * Hinemos Agentƻ֤ޤ
     * 
     * @return Hinemos Agentƻ
     */
    public ArrayList getAgentList() {
    	
    	MonitorAgentController agent = EjbConnectionManager.getConnectionManager().getAgentController();

        ArrayList records = null;
        
        try {
			records = agent.getAgentList();
		} catch (RemoteException e) {
			if(e instanceof AccessException){
				// ʤξ硢顼ɽ
	            MessageDialog.openInformation(null, Messages.getString("message"),
	                    Messages.getString("message.accesscontrol.16"));
			}
		} catch (CreateException e) {
		} catch (FinderException e) {
		} catch (SchedulerException e) {
		} catch (NamingException e) {
		}

        return records;
    }
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/HinemosAgentCore/src/com/clustercontrol/hinemosagent/action/GetAgent.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.hinemosagent.action;

import java.rmi.AccessException;
import java.rmi.RemoteException;
import java.util.ArrayList;

import javax.ejb.CreateException;
import javax.ejb.FinderException;
import javax.naming.NamingException;

import org.eclipse.jface.dialogs.MessageDialog;
import org.quartz.SchedulerException;

import com.clustercontrol.hinemosagent.ejb.session.MonitorAgentController;
import com.clustercontrol.hinemosagent.util.EjbConnectionManager;
import com.clustercontrol.monitor.run.bean.MonitorInfo;
import com.clustercontrol.util.Messages;

/**
 * Hinemos Agent監視を取得するクラスです。
 * 
 * @version 2.0.0
 * @since 2.0.0
 */
public class GetAgent {

    /**
     * Hinemos Agent監視情報を返します。
     * 
     * @param monitorId 状態監視ID
     * @return Hinemos Agent監視情報
     */
    public MonitorInfo getAgent(String monitorId) {
    	
    	MonitorAgentController agent = EjbConnectionManager.getConnectionManager().getAgentController();

    	MonitorInfo info = null;

    	try {
			info = agent.getAgentInfo(monitorId);
		} catch (RemoteException e) {
			if(e instanceof AccessException){
				// アクセス権なしの場合、エラーダイアログを表示する
	            MessageDialog.openInformation(null, Messages.getString("message"),
	                    Messages.getString("message.accesscontrol.16"));
			}
		} catch (CreateException e) {
			e.printStackTrace();
		} catch (FinderException e) {
			e.printStackTrace();
		} catch (SchedulerException e) {
			e.printStackTrace();
		} catch (NamingException e) {
			e.printStackTrace();
		}

        return info;
    }
    
    /**
     * Hinemos Agent監視一覧を返します。
     * 
     * @return Hinemos Agent監視一覧
     */
    public ArrayList getAgentList() {
    	
    	MonitorAgentController agent = EjbConnectionManager.getConnectionManager().getAgentController();

        ArrayList records = null;
        
        try {
			records = agent.getAgentList();
		} catch (RemoteException e) {
			if(e instanceof AccessException){
				// アクセス権なしの場合、エラーダイアログを表示する
	            MessageDialog.openInformation(null, Messages.getString("message"),
	                    Messages.getString("message.accesscontrol.16"));
			}
		} catch (CreateException e) {
		} catch (FinderException e) {
		} catch (SchedulerException e) {
		} catch (NamingException e) {
		}

        return records;
    }
}
